==> seahorse-0.9.2.tar.gz: seahorse-0.9.2/libseahorse/seahorse-passphrase.h <==
/*
 * Seahorse
 *
 * Copyright (C) 2006 Nate Nielsen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __SEAHORSE_PASSPHRASE__
#define __SEAHORSE_PASSPHRASE__

#include <gpgme.h>

#define SEAHORSE_PASS_BAD    0x00000001
#define SEAHORSE_PASS_NEW    0x01000000

GtkDialog*      seahorse_passphrase_prompt_show     (const gchar *title, 
                                                     const gchar *description, 
                                                     const gchar *prompt, 
                                                     const gchar *errmsg);
                                                     
const gchar*    seahorse_passphrase_prompt_get      (GtkDialog *dialog);

gpgme_error_t   seahorse_passphrase_get             (gconstpointer dummy,
                                                     const gchar *passphrase_hint, 
                                                     const char* passphrase_info, 
                                                     int prev_bad, int fd);
 
typedef enum {
    SEAHORSE_AGENT_UNKNOWN,
    SEAHORSE_AGENT_NONE,
    SEAHORSE_AGENT_OTHER,
    SEAHORSE_AGENT_SEAHORSE
} SeahorseAgentType;

SeahorseAgentType seahorse_passphrase_detect_agent ();

#endif /* __SEAHORSE_PASSPHRASE__ */

==> seahorse-1.0.1.tar.gz: seahorse-1.0.1/libseahorse/seahorse-passphrase.h <==
/*
 * Seahorse
 *
 * Copyright (C) 2006 Nate Nielsen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __SEAHORSE_PASSPHRASE__
#define __SEAHORSE_PASSPHRASE__

#include <gpgme.h>

#define SEAHORSE_PASS_BAD    0x00000001
#define SEAHORSE_PASS_NEW    0x01000000

GtkDialog*      seahorse_passphrase_prompt_show     (const gchar *title,
                                                     const gchar *description,
                                                     const gchar *prompt,
                                                     const gchar *check,
                                                     gboolean confirm);
                                                     
const gchar*    seahorse_passphrase_prompt_get      (GtkDialog *dialog);

gboolean        seahorse_passphrase_prompt_checked  (GtkDialog *dialog);

gpgme_error_t   seahorse_passphrase_get             (gconstpointer dummy,
                                                     const gchar *passphrase_hint, 
                                                     const char* passphrase_info, 
                                                     int prev_bad, int fd);

typedef enum {
    SEAHORSE_AGENT_UNKNOWN,
    SEAHORSE_AGENT_NONE,
    SEAHORSE_AGENT_OTHER,
    SEAHORSE_AGENT_SEAHORSE
} SeahorseAgentType;

SeahorseAgentType seahorse_passphrase_detect_agent ();

#endif /* __SEAHORSE_PASSPHRASE__ */
